@@ -1,6 +1,9 @@
 package Sys::Info::Driver::Windows;
 use strict;
 use warnings;
+
+our $VERSION = '0.76';
+
 use base qw( Exporter );
 use Carp qw( croak    );
 use Sys::Info::Constants qw( WIN_B24_DIGITS );
@@ -10,11 +13,8 @@ use constant SM_TABLETPC    => 86; # Windows XP Tablet PC edition
 use constant SM_MEDIACENTER => 87; # Windows XP, Media Center Edition
 use constant SM_STARTER     => 88; # Windows XP Starter Edition
 use constant SM_SERVERR2    => 89; # Windows Server 2003 R2
-
 use constant SERIAL_BASE    => 24;
 
-# Win32::SystemInfo::CpuUsage ???
-
 use XSLoader;
 
 my %REGISTRY;
@@ -31,14 +31,14 @@ BEGIN {
         );
         1;
     };
+
     if ( $@ || ! $eok ) {
         my $error = $@ || '<unknown error>';
-        croak "Error loading Win32::TieRegistry-: $error";
+        croak "Error loading Win32::TieRegistry: $error";
     }
 }
 
-our $VERSION = '0.74';
-our @EXPORT  = qw(  );
+our @EXPORT;
 our %EXPORT_TAGS = (
     metrics => [qw/
         GetSystemMetrics
@@ -47,12 +47,10 @@ our %EXPORT_TAGS = (
         SM_SERVERR2
         SM_STARTER
     /],
-    info => [qw/
-        GetSystemInfo
-    /],
-    WMI => [qw/ WMI WMI_FOR /],
-    etc => [qw/decode_serial_key/],
-    reg => [ qw( registry ) ],
+    info => [ qw/ GetSystemInfo CPUFeatures / ],
+    WMI  => [ qw/ WMI WMI_FOR               / ],
+    etc  => [ qw/ decode_serial_key         / ],
+    reg  => [ qw/ registry                  / ],
 );
 our @EXPORT_OK    = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
@@ -120,15 +118,15 @@ Sys::Info::Driver::Windows - Windows driver for Sys::Info
 
 =head1 SYNOPSIS
 
-    use Sys::Info::Driver::Windows::XS qw(:metrics);
+    use Sys::Info::Driver::Windows qw(:metrics);
     if ( GetSystemMetrics(SM_SERVERR2) ) {
         # do something ...
     }
 
 =head1 DESCRIPTION
 
-This document describes version C<0.74> of C<Sys::Info::Driver::Windows>
-released on C<25 May 2010>.
+This document describes version C<0.76> of C<Sys::Info::Driver::Windows>
+released on C<18 July 2010>.
 
 This is the main module in the C<Windows> driver collection.
 
@@ -141,6 +139,10 @@ None.
 The following functions will be automatically exported when the module
 is used.
 
+=head2 CPUFeatures
+
+TODO
+
 =head2 registry
 
 Returns a C<Win32::TieRegistry> hashref.
@@ -203,7 +205,7 @@ Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
