@@ -7,11 +7,12 @@ use base qw(
     Sys::Info::Driver::Windows::Device::CPU::WMI
 );
 use Sys::Info::Constants       qw( :windows_reg    );
-use Sys::Info::Driver::Windows qw( :info :reg :WMI );
+use Sys::Info::Driver::Windows::Constants;
+use Sys::Info::Driver::Windows qw( :info :reg :WMI CPUFeatures );
 use Carp                       qw( croak           );
 use Win32::OLE                 qw( in              );
 
-our $VERSION = '0.74';
+our $VERSION = '0.76';
 my $REG;
 $REG = registry()->{ +WIN_REG_CPU_KEY } if registry()->{ +WIN_REG_HW_KEY };
 
@@ -50,6 +51,7 @@ sub identify {
                     or $self->_from_registry
                     or $self->SUPER::identify(@_)
                     or croak('Failed to identify CPU');
+        $self->_set_flags( \@cache );
         $self->{META_DATA} = [ @cache ];
     }
     return $self->_serve_from_cache(wantarray);
@@ -57,6 +59,48 @@ sub identify {
 
 # ------------------------[ P R I V A T E ]------------------------ #
 
+sub _set_flags {
+    my($self, $cpu) = @_;
+
+    my %feat = CPUFeatures();
+    my $c    = 'Sys::Info::Driver::Windows::Constants';
+
+    my $get_symbols = sub {
+        # fetch the related constants
+        my $regex = shift || die "Regex missing\n";
+        no strict qw( refs );
+        return grep { $_ =~ $regex } keys %{ $c . q{::} };
+    };
+
+    my $cf = $feat{CpuFeatures};
+    my $f  = $feat{Flags};
+    my $k  = $feat{KFBits};
+    my $ff = $feat{FeatureFlags};
+    my @flags;
+
+    foreach my $flag ( $get_symbols->( qr{ \A CF_ }xms ) ){
+        push @flags, $flag if $f & $c->$flag();
+    }
+
+    foreach my $flag ( $get_symbols->( qr{ \A KF_ }xms ) ){
+        push @flags, $flag if $k & $c->$flag();
+    }
+
+    foreach my $flag ( $get_symbols->( qr{ \A FT_ }xms ) ){
+        push @flags, $flag if $ff & $c->$flag();
+    }
+
+    foreach my $e ( @flags ) {
+        $e =~ s{ \A (?: CF|KF|FT )_ }{}xms;
+    }
+
+    my %fbuf = map { lc $_ => 1 } @flags;
+    @flags = sort keys %fbuf;
+
+    $cpu->[$_]{flags} = [ @flags ] for 0..$#{$cpu};
+    return;
+}
+
 # $REG->{'0/FeatureSet'}
 # $REG->{'0/Update Status'}
 sub _from_registry {
@@ -114,8 +158,8 @@ Sys::Info::Driver::Windows::Device::CPU - Windows CPU Device Driver
 
 =head1 DESCRIPTION
 
-This document describes version C<0.74> of C<Sys::Info::Driver::Windows::Device::CPU>
-released on C<25 May 2010>.
+This document describes version C<0.76> of C<Sys::Info::Driver::Windows::Device::CPU>
+released on C<18 July 2010>.
 
 Uses C<WMI>, C<Registry> and C<ENV> to identify the CPU.
 
@@ -149,7 +193,7 @@ Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
