@@ -3,11 +3,16 @@ use strict;
 use warnings;
 use Sys::Info::Driver::Windows qw( :metrics :WMI );
 
-## no critic (ValuesAndExpressions::ProhibitMagicNumbers, ValuesAndExpressions::RequireNumberSeparators)
+use constant RE_X86   => qr{  X86}xmsi;
+use constant RE_AMD64 => qr{AMD64}xmsi;
+use constant RE_IA64  => qr{ IA64}xmsi;
 
-our $VERSION = '0.74';
+## no critic ( ValuesAndExpressions::ProhibitMagicNumbers    )
+## no critic ( ValuesAndExpressions::RequireNumberSeparators )
 
-my %VISTA_EDITION = ( # OK
+our $VERSION = '0.76';
+
+my %VISTA_EDITION = (
    0x00000006 => q{Business Edition},
    0x00000010 => q{Business N Edition},
    0x00000004 => q{Enterprise Edition},
@@ -18,7 +23,7 @@ my %VISTA_EDITION = ( # OK
    0x00000001 => q{Ultimate Edition},
 );
 
-my %SERVER08_EDITION = ( # OK
+my %SERVER08_EDITION = (
    0x00000012 => q{Cluster Server Edition},
    0x00000008 => q{Datacenter Edition Full Installation}, # Windows Server ...
    0x0000000C => q{Datacenter Edition Core Installation}, # Windows Server ...
@@ -41,7 +46,7 @@ my %SERVER08_EDITION = ( # OK
 sub _cpu_arch {
     my $self = shift;
     require Sys::Info::Device;
-    my $cpu  = Sys::Info::Device->new( 'CPU' );
+    my $cpu = Sys::Info::Device->new( 'CPU' );
     foreach my $cpu ( $cpu->identify ) {
         # get the first available one
         return $cpu->{architecture} if $cpu->{architecture};
@@ -58,62 +63,76 @@ sub _xp_or_03 {
     my $mask   = $OSV->{RAW}{SUITEMASK};
     my $pt     = $OSV->{RAW}{PRODUCTTYPE};
     my $arch   = $self->_cpu_arch || q{};
-    my $metric = GetSystemMetrics(SM_SERVERR2);
+    my $metric = GetSystemMetrics( SM_SERVERR2 );
 
     ${$osname_ref} = 'Windows Server 2003';
 
-    if ( $mask & 0x00000080 ) {
-        if ( $metric ) {
-            ${$edition_ref} = $arch =~ m{X86}xmsi   ? 'R2 Datacenter Edition'
-                            : $arch =~ m{AMD64}xmsi ? 'R2 x64 Datacenter Edition'
-                            :                         'unknown';
-        }
-        else {
-            ${$edition_ref} = $arch =~m{X86}xmsi    ? 'Datacenter Edition'
-                            : $arch =~m{AMD64}xmsi  ? 'Datacenter x64 Edition'
-                            : $arch =~m{IA64}xmsi   ? 'Datacenter Edition Itanium'
-                            :                         'unknown';
-        }
-    }
-    elsif ( $mask & 0x00000002 ) {
-        if ( $metric ) {
-            ${$edition_ref} = $arch =~ m{X86}xmsi   ? 'R2 Enterprise Edition'
-                            : $arch =~ m{AMD64}xmsi ? 'R2 x64 Enterprise Edition'
-                            :                         'unknown';
-        }
-        else {
-            ${$edition_ref} = $arch =~ m{X86}xmsi   ? 'Enterprise Edition'
-                            : $arch =~ m{AMD64}xmsi ? 'Enterprise x64 Edition'
-                            : $arch =~ m{IA64}xmsi  ? 'Enterprise Edition Itanium'
-                            :                         'unknown';
-        }
+    my $id = $mask & 0x00000080 ? 1
+           : $mask & 0x00000002 ? 2
+           :                      3
+           ;
+    my $dispatch = '_xp_or_03_case' . $id;
+    return $self->$dispatch( $metric, $arch, $edition_ref, $osname_ref, $pt );
+}
+
+sub _xp_or_03_case1 {
+    my($self, $metric, $arch, $edition_ref) = @_;
+    if ( $metric ) {
+        ${$edition_ref} = $arch =~ RE_X86   ? 'R2 Datacenter Edition'
+                        : $arch =~ RE_AMD64 ? 'R2 x64 Datacenter Edition'
+                        :                     'unknown';
     }
     else {
-        if ( $metric ) {
-            ${$edition_ref} = $arch =~ m{X86}xmsi   ? 'R2 Standard Edition'
-                            : $arch =~ m{AMD64}xmsi ? 'R2 x64 Standard Edition'
-                            :                         'unknown';
-        }
-        elsif ( $pt > 1 ) {
-            ${$edition_ref} = $arch =~ m{X86}xmsi   ? 'Standard Edition'
-                            : $arch =~ m{AMD64}xmsi ? 'Standard x64 Edition'
-                            :                         'unknown';
-        }
-        elsif ( $pt == 1 ) {
-            ${$osname_ref}  = 'Windows XP';
-            ${$edition_ref} = $arch =~ m{IA64}xmsi  ? '64 bit Edition Version 2003'
-                            : $arch =~ m{AMD64}xmsi ? 'Professional x64 Edition'
-                            :                         'unknown';
-        }
-        else {
-            ${$edition_ref} = 'unknown';
-        }
+        ${$edition_ref} = $arch =~ RE_X86   ? 'Datacenter Edition'
+                        : $arch =~ RE_AMD64 ? 'Datacenter x64 Edition'
+                        : $arch =~ RE_IA64  ? 'Datacenter Edition Itanium'
+                        :                     'unknown';
+    }
+    return;
+}
+
+sub _xp_or_03_case2 {
+    my($self, $metric, $arch, $edition_ref) = @_;
+    if ( $metric ) {
+        ${$edition_ref} = $arch =~ RE_X86   ? 'R2 Enterprise Edition'
+                        : $arch =~ RE_AMD64 ? 'R2 x64 Enterprise Edition'
+                        :                     'unknown';
+    }
+    else {
+        ${$edition_ref} = $arch =~ RE_X86   ? 'Enterprise Edition'
+                        : $arch =~ RE_AMD64 ? 'Enterprise x64 Edition'
+                        : $arch =~ RE_IA64  ? 'Enterprise Edition Itanium'
+                        :                     'unknown';
+    }
+    return;
+}
+
+sub _xp_or_03_case3 {
+    my($self, $metric, $arch, $edition_ref, $osname_ref, $pt) = @_;
+    if ( $metric ) {
+        ${$edition_ref} = $arch =~ RE_X86   ? 'R2 Standard Edition'
+                        : $arch =~ RE_AMD64 ? 'R2 x64 Standard Edition'
+                        :                     'unknown';
+    }
+    elsif ( $pt > 1 ) {
+        ${$edition_ref} = $arch =~ RE_X86   ? 'Standard Edition'
+                        : $arch =~ RE_AMD64 ? 'Standard x64 Edition'
+                        :                     'unknown';
+    }
+    elsif ( $pt == 1 ) {
+        ${$osname_ref}  = 'Windows XP';
+        ${$edition_ref} = $arch =~ RE_IA64  ? '64 bit Edition Version 2003'
+                        : $arch =~ RE_AMD64 ? 'Professional x64 Edition'
+                        :                     'unknown';
+    }
+    else {
+        ${$edition_ref} = 'unknown';
     }
     return;
 }
 
 sub _xp_editions {
-    my $self = shift;
+    my $self        = shift;
     my $edition_ref = shift;
     my $osname_ref  = shift;
     my $OSV         = shift;
@@ -123,8 +142,8 @@ sub _xp_editions {
     ${$edition_ref} = GetSystemMetrics(SM_TABLETPC)    ? 'Tablet PC Edition'
                     : GetSystemMetrics(SM_MEDIACENTER) ? 'Media Center Edition'
                     : GetSystemMetrics(SM_STARTER)     ? 'Starter Edition'
-                    : $arch =~ m{x86}xmsi              ? 'Professional'
-                    : $arch =~ m{IA64}xmsi             ? '64-bit Edition for Itanium systems'
+                    : $arch =~ RE_X86                  ? 'Professional'
+                    : $arch =~ RE_IA64                 ? '64-bit Edition for Itanium systems'
                     :                                    q{};
     return;
 }
@@ -134,10 +153,8 @@ sub _2k_03_xp {
     my $edition_ref = shift;
     my $osname_ref  = shift;
     my $OSV         = shift;
-
     my $mask        = $OSV->{RAW}{SUITEMASK};
     my $pt          = $OSV->{RAW}{PRODUCTTYPE};
-
     ${$osname_ref}  = 'Windows 2000';
 
     if ( $mask & 0x00000080 ) { ## no critic (ControlStructures::ProhibitCascadingIfElse)
@@ -155,17 +172,17 @@ sub _2k_03_xp {
     elsif ( $mask & 0x00000400 ) {
         ${$osname_ref}  = 'Windows Server 2003';
         ${$edition_ref} = GetSystemMetrics(SM_SERVERR2) ? 'R2 Web Edition'
-                                                      : 'Web Edition';
+                                                        : 'Web Edition';
     }
     elsif ( $mask & 0x00004000) {
         ${$osname_ref}  = 'Windows Server 2003';
         ${$edition_ref} = GetSystemMetrics(SM_SERVERR2) ? 'R2 Compute Cluster Edition'
-                                                      : 'Compute Cluster Edition';
+                                                        : 'Compute Cluster Edition';
     }
     elsif ( $mask & 0x00002000) {
         ${$osname_ref}  = 'Windows Server 2003';
         ${$edition_ref} = GetSystemMetrics(SM_SERVERR2) ? 'R2 Storage'
-                                                      : 'Storage';
+                                                        : 'Storage';
     }
     elsif ($mask & 0x00000040 ) {
         ${$osname_ref}  = 'Windows XP';
@@ -224,7 +241,7 @@ sub _win7 {
         ${$edition_ref} = $win7;
     }
     else {
-        (my $caption = $item->Caption) =~ s{.+?Windows \s 7\s?}{}xms;
+        (my $caption = $item->Caption) =~ s{ .+? Windows \s 7 \s? }{}xms;
         ${$edition_ref} = $self->trim($caption) if $caption;
     }
     return;
@@ -246,8 +263,8 @@ None. Used internally.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.74> of C<Sys::Info::Driver::Windows::OS::Editions>
-released on C<25 May 2010>.
+This document describes version C<0.76> of C<Sys::Info::Driver::Windows::OS::Editions>
+released on C<18 July 2010>.
 
 Although there are not much Windows versions, there are ridiculously lots of
 editions of Windows versions after Windows 2000. This module uses C<WMI>,
@@ -271,7 +288,7 @@ Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
